==> jc-1.4.0.tar.gz: org/xml/sax/SAXParseException.h <==
// public class org.xml.sax.SAXParseException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException
// @dep_class bc82f475d377c075 org_xml_sax_SAXParseException

// header file dependencies
// @dep_header org_xml_sax_SAXException

#include "org/xml/sax/SAXException.h"

#ifndef _JC_org_xml_sax_SAXParseException_H_
#define _JC_org_xml_sax_SAXParseException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Locator$object;

// Typedefs
typedef struct _jc_org_xml_sax_SAXParseException$sub_refs	_jc_org_xml_sax_SAXParseException$sub_refs;
typedef struct _jc_org_xml_sax_SAXParseException$sub_nonrefs	_jc_org_xml_sax_SAXParseException$sub_nonrefs;
typedef struct _jc_org_xml_sax_SAXParseException$refs	_jc_org_xml_sax_SAXParseException$refs;
typedef struct _jc_org_xml_sax_SAXParseException$nonrefs	_jc_org_xml_sax_SAXParseException$nonrefs;
typedef struct _jc_org_xml_sax_SAXParseException$object	_jc_org_xml_sax_SAXParseException$object;

typedef const struct _jc_org_xml_sax_SAXParseException$vmethods	_jc_org_xml_sax_SAXParseException$vmethods;
typedef const struct _jc_org_xml_sax_SAXParseException$vtable	_jc_org_xml_sax_SAXParseException$vtable;
typedef const struct _jc_org_xml_sax_SAXParseException$vtype	_jc_org_xml_sax_SAXParseException$vtype;

// Constructors
extern void _jc_org_xml_sax_SAXParseException$method$_init$bb9fa96bc47f2907(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, jint);
extern void _jc_org_xml_sax_SAXParseException$method$_init$aff7713b79545654(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, jint, struct _jc_java_lang_Exception$object *);
extern void _jc_org_xml_sax_SAXParseException$method$_init$2c023c34f2986b15(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_org_xml_sax_SAXParseException$method$_init$63b4d32e743dfe3b(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_Exception$object *);

// Virtual methods
extern jint _jc_org_xml_sax_SAXParseException$method$getColumnNumber$b311b369fd1c2551(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
extern jint _jc_org_xml_sax_SAXParseException$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_SAXParseException$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_SAXParseException$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
extern void _jc_org_xml_sax_SAXParseException$method$init$e6150eb52ab51bea(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$getColumnNumber$b311b369fd1c2551;
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$init$e6150eb52ab51bea;

// Virtual methods structure
struct _jc_org_xml_sax_SAXParseException$vmethods {
	jint	(*getColumnNumber$b311b369fd1c2551)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
	void	(*init$e6150eb52ab51bea)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, jint);
};

// Vtable
struct _jc_org_xml_sax_SAXParseException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
	_jc_org_xml_sax_SAXParseException$vmethods	org_xml_sax_SAXParseException;
};

// Vtype
struct _jc_org_xml_sax_SAXParseException$vtype {
	_jc_type			type;
	_jc_org_xml_sax_SAXParseException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_SAXParseException$sub_refs {
	struct _jc_java_lang_String$object	*publicId;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_org_xml_sax_SAXParseException$refs {
    _jc_org_xml_sax_SAXParseException$sub_refs	org_xml_sax_SAXParseException;
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_SAXParseException$sub_nonrefs {
	jint	lineNumber;
	jint	columnNumber;
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_SAXParseException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
    _jc_org_xml_sax_SAXParseException$sub_nonrefs	org_xml_sax_SAXParseException;
};

// Object instance structure
struct _jc_org_xml_sax_SAXParseException$object {
	_jc_org_xml_sax_SAXParseException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_SAXParseException$vtype	*vtype;
	_jc_org_xml_sax_SAXParseException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_SAXParseException$vtype _jc_org_xml_sax_SAXParseException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_SAXParseException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_SAXParseException$class_object;

#endif	/* _JC_org_xml_sax_SAXParseException_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/SAXParseException.h <==
// public class org.xml.sax.SAXParseException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException
// @dep_class bc82f475d377c075 org_xml_sax_SAXParseException

// header file dependencies
// @dep_header org_xml_sax_SAXException

#include "org/xml/sax/SAXException.h"

#ifndef _JC_org_xml_sax_SAXParseException_H_
#define _JC_org_xml_sax_SAXParseException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Locator$object;

// Typedefs
typedef struct _jc_org_xml_sax_SAXParseException$sub_refs	_jc_org_xml_sax_SAXParseException$sub_refs;
typedef struct _jc_org_xml_sax_SAXParseException$sub_nonrefs	_jc_org_xml_sax_SAXParseException$sub_nonrefs;
typedef struct _jc_org_xml_sax_SAXParseException$refs	_jc_org_xml_sax_SAXParseException$refs;
typedef struct _jc_org_xml_sax_SAXParseException$nonrefs	_jc_org_xml_sax_SAXParseException$nonrefs;
typedef struct _jc_org_xml_sax_SAXParseException$object	_jc_org_xml_sax_SAXParseException$object;

typedef const struct _jc_org_xml_sax_SAXParseException$vmethods	_jc_org_xml_sax_SAXParseException$vmethods;
typedef const struct _jc_org_xml_sax_SAXParseException$vtable	_jc_org_xml_sax_SAXParseException$vtable;
typedef const struct _jc_org_xml_sax_SAXParseException$vtype	_jc_org_xml_sax_SAXParseException$vtype;

// Constructors
extern void _jc_org_xml_sax_SAXParseException$method$_init$bb9fa96bc47f2907(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXParseException$method$_init$aff7713b79545654(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, jint, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXParseException$method$_init$2c023c34f2986b15(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXParseException$method$_init$63b4d32e743dfe3b(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_org_xml_sax_SAXParseException$method$getColumnNumber$b311b369fd1c2551(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern jint _jc_org_xml_sax_SAXParseException$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_SAXParseException$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_SAXParseException$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXParseException$method$init$e6150eb52ab51bea(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$getColumnNumber$b311b369fd1c2551;
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_org_xml_sax_SAXParseException$method_info$init$e6150eb52ab51bea;

// Virtual methods structure
struct _jc_org_xml_sax_SAXParseException$vmethods {
	jint	(*getColumnNumber$b311b369fd1c2551)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	void	(*init$e6150eb52ab51bea)(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_xml_sax_SAXParseException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
	_jc_org_xml_sax_SAXParseException$vmethods	org_xml_sax_SAXParseException;
};

// Vtype
struct _jc_org_xml_sax_SAXParseException$vtype {
	_jc_type			type;
	_jc_org_xml_sax_SAXParseException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_SAXParseException$sub_refs {
	struct _jc_java_lang_String$object	*publicId;
	struct _jc_java_lang_String$object	*systemId;
};

// Reference instance fields (object)
struct _jc_org_xml_sax_SAXParseException$refs {
    _jc_org_xml_sax_SAXParseException$sub_refs	org_xml_sax_SAXParseException;
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_SAXParseException$sub_nonrefs {
	jint	lineNumber;
	jint	columnNumber;
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_SAXParseException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
    _jc_org_xml_sax_SAXParseException$sub_nonrefs	org_xml_sax_SAXParseException;
};

// Object instance structure
struct _jc_org_xml_sax_SAXParseException$object {
	_jc_org_xml_sax_SAXParseException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_SAXParseException$vtype	*vtype;
	_jc_org_xml_sax_SAXParseException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_SAXParseException$vtype _jc_org_xml_sax_SAXParseException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_SAXParseException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_SAXParseException$class_object;

#endif	/* _JC_org_xml_sax_SAXParseException_H_ */
